==> nextcloud-29.0.5.tgz: nextcloud/apps/comments/l10n/gl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Vde. comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Vde. comentou en %1$s",
    "You commented on {file}" : "Vde. comentou en {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentou en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para ficheiros",
    "Files" : "Ficheiros",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Mencionárono en «{file}», nun comentario dunha conta que xa foi eliminada",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mencionouno a Vde. nun comentario en «{file}»",
    "Files app plugin to add comments to files" : "Complemento da aplicación de ficheiros para engadir comentarios aos ficheiros",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Eliminar comentario",
    "Cancel edit" : "Cancelar a edición",
    "New comment" : "Comentario novo",
    "Write a comment …" : "Escriba un comentario…",
    "Post comment" : "Publicar comentario",
    "@ for mentions, : for emoji, / for smart picker" : "@ para mencións, : para «emoji», / para selector intelixente",
    "Could not reload comments" : "Non foi posíbel volver cargar os comentarios",
    "No comments yet, start the conversation!" : "Aínda non hai comentarios, comeza a conversa!",
    "No more messages" : "Non hai máis mensaxes",
    "Retry" : "Tentar de novo",
    "Failed to mark comments as read" : "Produciuse un fallo ao marcar os comentarios como lidos",
    "Unable to load the comments list" : "Non é posíbel cargar a lista de comentarios",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario novo","{unread} comentarios novos"],
    "Comment" : "Comentario",
    "An error occurred while trying to edit the comment" : "Produciuse un erro cando tentaba editar o comentario",
    "Comment deleted" : "Comentario eliminado",
    "An error occurred while trying to delete the comment" : "Produciuse un erro cando tentaba eliminar o comentario",
    "An error occurred while trying to create the comment" : "Produciuse un erro cando tentaba crear o comentario",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Mencionárono en «{file}», nun comentario dun usuario que xa foi eliminado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.14.tgz: nextcloud/apps/comments/l10n/gl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Vde. comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Vde. comentou en %1$s",
    "You commented on {file}" : "Vde. comentou en {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentou en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para ficheiros",
    "Files" : "Ficheiros",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Mencionárono en «{file}», nun comentario dunha conta que xa foi eliminada",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mencionouno a Vde. nun comentario en «{file}»",
    "Files app plugin to add comments to files" : "Complemento da aplicación de ficheiros para engadir comentarios aos ficheiros",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Eliminar comentario",
    "Cancel edit" : "Cancelar a edición",
    "New comment" : "Comentario novo",
    "Write a comment …" : "Escriba un comentario…",
    "Post comment" : "Publicar comentario",
    "@ for mentions, : for emoji, / for smart picker" : "@ para mencións, : para «emoji», / para selector intelixente",
    "Could not reload comments" : "Non foi posíbel volver cargar os comentarios",
    "Failed to mark comments as read" : "Produciuse un fallo ao marcar os comentarios como lidos",
    "Unable to load the comments list" : "Non é posíbel cargar a lista de comentarios",
    "No comments yet, start the conversation!" : "Aínda non hai comentarios, comeza a conversa!",
    "No more messages" : "Non hai máis mensaxes",
    "Retry" : "Volver tentar",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario novo","{unread} comentarios novos"],
    "Comment" : "Comentario",
    "An error occurred while trying to edit the comment" : "Produciuse un erro cando tentaba editar o comentario",
    "Comment deleted" : "Comentario eliminado",
    "An error occurred while trying to delete the comment" : "Produciuse un erro cando tentaba eliminar o comentario",
    "An error occurred while trying to create the comment" : "Produciuse un erro cando tentaba crear o comentario"
},
"nplurals=2; plural=(n != 1);");
